encode_instruction

Function encode_instruction 

pub fn encode_instruction(
    instr: &Instruction,
    arch: Arch,
) -> Result<EncodedInstr, AsmError>
Errors

Returns Err(AsmError) if the instruction mnemonic is unknown, the operand combination is invalid, or the target architecture is not supported.