parse

Function parse 

pub fn parse(tokens: &[Token<'_>]) -> Result<Vec<Statement>, AsmError>
Parse a token stream into a list of IR statements.

Errors

Returns Err(AsmError) if the token stream contains an unexpected token, a malformed directive, or an invalid instruction syntax.